@@ -1,5 +1,5 @@
 `import.from.Access` <-
-function(file=file.choose(),table="community",sitenames="sites",column="species",value="abundance",factor="",level="") {
+function(file=file.choose(),table="community",sitenames="sites",column="species",value="abundance",factor="",level="",cepnames=FALSE) {
     if (!require(RODBC)) {stop("Requires package RODBC")}
     dataplace <- odbcConnectAccess(file)
     TABLES <- c("community", "environmental", "stacked")
@@ -12,7 +12,11 @@ function(file=file.choose(),table="community",sitenames="sites",column="species"
     }
     close(dataplace)
     rownames(result) <- make.names(rownames(result),unique=T)
-    colnames(result) <- make.names(colnames(result),unique=T)
+    if (cepnames == TRUE) {
+        colnames(result) <- make.cepnames(colnames(result))
+    }else{
+        colnames(result) <- make.names(colnames(result),unique=T)
+    }
     return(result)
 }
 
